:description: falco release history

Changelog
=========

.. changelog::
    :changelog-url: https://github.com/Tobi-De/falco/releases
    :github: https://github.com/Tobi-De/falco/releases
    :pypi: https://pypi.org/project/falco-cli/
